pub enum VisibleColKind {
Leaf,
Collapsed,
Subtotal,
GrandTotal,
}Expand description
What kind of column a visible pivot column is.
Variants
Leaf
An innermost column group — a plain value column.
Collapsed
A collapsed column group shown as a single subtotal column.
Subtotal
The “Total” column appended after an expanded group
(when PivotConfig::show_column_subtotals is on).
GrandTotal
The grand-total column at the right.